@@ -1,10 +1,10 @@
 '''
 Author: BDFD
 Date: 2022-03-01 17:28:34
-LastEditTime: 2022-04-24 08:09:55
+LastEditTime: 2022-06-24 13:11:58
 LastEditors: BDFD
 Description: 
-FilePath: \5.2-PyPi-WES_Calculation\WES_Calculation\greenampt.py
+FilePath: \Section5.2-PyPi-WES_Calculation\WES_Calculation\greenampt.py
 '''
 
 import matplotlib.pyplot as plt
@@ -349,7 +349,9 @@ def greenampt(thetai, thetas, Psi, K, dti, nin, dd, i, iyesno, ss1, ss2, ss3):
     #plt.rcParams['axes.unicode_minus'] = False
     #mpl.rcParams['axes.unicode_minus'] = False
     #matplotlib.rc('font', family='FangSong')
-    #mpl.rcParams['font.sans-serif'] = ['Microsoft YaHei'] 
+    #mpl.rcParams['font.sans-serif'] = ['Microsoft YaHei']
+    plt.savefig('./static/greenampt.jpg')
+    # plt.show()
     img = io.BytesIO()
     plt.savefig(img, format='png')
     img.seek(0)
