@@ -1,7 +1,7 @@
 '''
 Author: BDFD
 Date: 2022-02-24 15:23:11
-LastEditTime: 2022-06-14 11:55:20
+LastEditTime: 2022-06-24 12:48:23
 LastEditors: BDFD
 Description: 
 FilePath: \Section5.2-PyPi-WES_Calculation\WES_Calculation\gumbel.py
@@ -391,6 +391,7 @@ def gumbel(pq, unitt, unitx, i1, i2, i3, meanx, sdx, n, dataolist):
 
         plt.legend()
         plt.rcParams['font.sans-serif'] = ['KaiTi']#FangSong
+        plt.savefig('./static/gumbel.jpg')
         # plt.show()
         img = io.BytesIO()
         plt.savefig(img, format='png')
@@ -398,4 +399,4 @@ def gumbel(pq, unitt, unitx, i1, i2, i3, meanx, sdx, n, dataolist):
         plot_url = base64.b64encode(img.getvalue()).decode()
         plt.close("all")
         # return plot_url
-    return plot_url, n, note1, note2, note3, data3, note4, data4, note5, data5, data6, heading1, heading2, ending
\ No newline at end of file
+    return plot_url, nlC2, n, note1, note2, note3, data3, note4, data4, note5, data5, data6, heading1, heading2, ending
\ No newline at end of file
