@@ -1,10 +1,10 @@
 '''
 Author: BDFD
 Date: 2022-04-20 13:16:40
-LastEditTime: 2022-05-04 14:07:19
+LastEditTime: 2022-06-24 13:12:33
 LastEditors: BDFD
 Description: 
-FilePath: \5.2-PyPi-WES_Calculation\WES_Calculation\wave.py
+FilePath: \Section5.2-PyPi-WES_Calculation\WES_Calculation\wavespectra.py
 '''
 import matplotlib.pyplot as plt
 from matplotlib.ticker import FixedLocator, FixedFormatter
@@ -706,8 +706,8 @@ def wave(c1, d, X, U, el, gamma, Hs, Tz, Ts, Tp):
     plt.ylabel('S (m$^2$s)')         
     plt.legend()
     # plt.rcParams['font.sans-serif'] = ['Kaiti']  # ['FangSong']
+    plt.savefig('./static/wavespectra.jpg')
     # plt.show()
-
     img = io.BytesIO()
     plt.savefig(img, format='png')
     img.seek(0)
